@@ -1,5 +1,5 @@
 package Strehler::Dancer2::Plugin::EX;
-$Strehler::Dancer2::Plugin::EX::VERSION = '1.6.7';
+$Strehler::Dancer2::Plugin::EX::VERSION = '1.6.8';
 use strict;
 use warnings;
 
@@ -35,11 +35,7 @@ register 'slug' => sub {
         my $article = $class->get_by_slug($slug, $language);
         if( ! $article || ! $article->exists() || ($category && $article->get_category_name() ne $category))
         {
-            Dancer2::Core::Error->new(
-                response => $dsl->response(),
-                status   => 404,
-                message  => "Access denied",
-            )->throw
+            $dsl->send_error("Not found", 404);
         }
         else
         {
