@@ -1,6 +1,6 @@
 package Demo;
 use Dancer2;
-use Strehler::Dancer2::Plugin;
+use Strehler::Dancer2::Plugin::Admin;
 
 
 get '/' => sub {
